# CHANGELOG

## 1.1.0 (2025-06-24)

- Support named tuples in sub-select expressions

## 1.0.1 (2025-06-23)

- fixed and evolved documentation
- doctests

## 1.0.0 (2025-06-23)

- first release
  - `find_all()`
  - with JSON Path-like expression builder
